/*
 * Copyright (c) 2007, to-do. All rights reserved.
 */
#ifndef _UTIL_H_
#define _UTIL_H_

#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <math.h>
#include <time.h>
#include <limits.h>
#include <errno.h>
#include <assert.h>
#include <unistd.h>
#include <glob.h>
#include <sys/stat.h>
#include <sys/time.h>
#include <sys/mman.h>

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

int   strnncmp(char*, int, char*, int);
int   strrnncmp(char*, int, char*, int);

int   strtoh(char*, int);

int   iscrlf(int);

int   isoctal(int);
int   xtoi(int);
int   itoX(int);
int   c_to_meta(int*, int);
int   meta_to_c(char**, int);

char* c_to_entity(int);
int   entity_to_c(char **);

#endif /* _UTIL_H_ */
